/*
 * (c) 2008 David Simmons
 *
 * This code is licensed under the same license as Roller itself:
 *
 * David Simmons licenses this file to You
 * under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.  For additional information regarding
 * copyright in this work, please see the NOTICE file in the top level
 * directory of this distribution.
 */

package com.davidsimmons.roller;

import org.apache.roller.weblogger.business.MultiWeblogURLStrategy;
import org.apache.roller.weblogger.pojos.Weblog;

public class CustomURLStrategy extends MultiWeblogURLStrategy {

    // the following weblogs will have the first component of the
    // path removed from their URLs.
    protected String[] specialWeblogs = {
        "cafbit",
        "caffbit",
        "simmons"
    };

    // is the specified weblog on the special list?
    protected boolean isSpecial(Weblog weblog) {
        String handle = weblog.getHandle();
        for (String specialWeblog : specialWeblogs) {
            if (handle.equals(specialWeblog)) {
                return true;
            }
        }
        return false;
    }

    // use a regular expression to remove the first component
    // of the URL's path.
    protected String removeFirstPathComponent(String url) {
        if (url.startsWith("http")) {
            // full URLs.
            return url.replaceFirst("^(http.*://[^/]+)/[^/]+(/.*)$", "$1$2");
        } else if (url.startsWith("/")) {
            // URLs that are not qualified with a protocol and hostname
            return url.replaceFirst("^/[^/]+(/.*)$", "$1");
        } else {
            // unknown case
            return url;
        }
    }

    // overridden method

    public String getWeblogURL(Weblog weblog, String locale, boolean absolute) {

        // MultiWeblogURLStrategy seems to think it's important to check for
        // a null weblog reference, so we'll do the same thing here.
        if (weblog == null) {
            return null;
        }

        // let MultiWeblogURLStrategy's method do its thing
        String url = super.getWeblogURL(weblog, locale, absolute);

        // if this weblog is on our special list, process the URL.
        if (isSpecial(weblog)) {
            url = removeFirstPathComponent(url);
        }

        return url;
    }

}

